"""This is print_item.py module, which print item that may contain nested collection"""


def print_item(items, level):
    if not isinstance(items, list):
        for i in range(level):
            print('\t', end='')
        print(items)
    else:
        for i in items:
            print_item(i, level + 1)



from distutils.core import setup

setup(
    name='print_item',
    version='1.1.0',
    py_modules=['print_item'],
    author='quoccuong',
    author_email='tqcuong.secure@gmail.com',
    url='',
    description='A simple print item mays contain nested list',
)
